colour.models.dataset.beta_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.beta_rgb Module

## Beta RGB Colourspace

Defines the Beta RGB colourspace:

- `BETA_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.brucelindbloom.com/WorkingSpaceInfo.html (Last accessed 11 April 2014)

`colour.models.dataset.beta_rgb.` `BETA_RGB_PRIMARIES` = array([[ 0.6888, 0.3112], [ 0.1986, 0.7551], [ 0.1265, 0.0352]])

  Beta RGB colourspace primaries.

  BETA_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.beta_rgb.` `BETA_RGB_WHITEPOINT` = (0.34567, 0.3585)

  Beta RGB colourspace whitepoint.

  BETA_RGB_WHITEPOINT : tuple

`colour.models.dataset.beta_rgb.` `BETA_RGB_TO_XYZ_MATRIX` = array([[ 6.71248095e-01, 1.74584298e-01, 1.18379601e-01], [ 3.03270045e-01, 6.63789544e-01, 3.29404107e-02], [ 5.40966239e-17, 4.07011732e-02, 7.84487111e-01]])

  Beta RGB colourspace to CIE XYZ colourspace matrix.

  BETA_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.beta_rgb.` `XYZ_TO_BETA_RGB_MATRIX` = array([[ 1.68324101, -0.42823986, -0.23602045], [-0.77101888, 1.70654822, 0.04468972], [ 0.04000241, -0.08854003, 1.27239959]])

  CIE XYZ colourspace to Beta RGB colourspace matrix.

  XYZ_TO_BETA_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.beta_rgb.` `BETA_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Beta RGB colourspace.

  BETA_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.beta_rgb.` `BETA_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Beta RGB colourspace to linear.

  BETA_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.beta_rgb.` `BETA_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d1d0>

  Beta RGB colourspace.

  BETA_RGB_COLOURSPACE : RGB_Colourspace